<?php
/*
Plugin Name: Garuda Keen Rating
Plugin URI: https://wordpress.org/plugins/garuda-keen-rating
Description: A simple star rating plugin for page and any type of post
Version: 1.0.2
Author: Mahedi Hasan
Author URI: https://profiles.wordpress.org/mahedy150101/
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: garuda-keen-rating
*/

defined('ABSPATH') || exit;

if (!defined('GARUDA_KEEN_PLUGIN_VERSION')) {
    define('GARUDA_KEEN_PLUGIN_VERSION', '1.0.0');
}
if (!defined('GARUDA_KEEN_PLUGIN_DIR')) {
    define('GARUDA_KEEN_PLUGIN_DIR', plugin_dir_url(__FILE__));
}

if (!function_exists('gkr_plugin_scripts')) {
    function gkr_plugin_scripts()
    {

        wp_enqueue_style('keen-font-awesome', GARUDA_KEEN_PLUGIN_DIR . 'assets/css/fontawesome.css');
        wp_enqueue_style('garuda-keen-rating', GARUDA_KEEN_PLUGIN_DIR . 'assets/css/style.css');
        wp_enqueue_script('garuda-keen-rating-script', GARUDA_KEEN_PLUGIN_DIR . 'assets/js/script.js', array('jquery'), GARUDA_KEEN_PLUGIN_VERSION, true);

        wp_enqueue_style('dashicons');

        wp_localize_script('garuda-keen-rating-script', 'gkr_object', [
            'ajax_url' => admin_url('admin-ajax.php')
        ]);
    }
    add_action('wp_enqueue_scripts', 'gkr_plugin_scripts');
}

//Create the rating interface.
add_shortcode('keen_star_rating', 'gkr_field');
function gkr_field()
{

    global $wpdb;
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    $table_name = $wpdb->prefix . "keen_rating";
    $post_id = get_the_ID();
    $total_row = $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE (post_id = '" . $post_id . "')");

    $gkr_data = get_option('gkr_options');
    $color = $gkr_data['gkr_color_scheme'];
    $hovar_color = $gkr_data['gkr_hovar_color'];
    $selected_color = $gkr_data['gkr_selected_color'];
    $star_size = $gkr_data['gkr_font_size'];
    $user_value = $gkr_data['gkr_checkbox'];
    if ($user_value == 1) {
        echo '<style type="text/css">
    .keen-result {                                                                          display: none;                                                  
    }
    </style>';
    }

    echo '<style type="text/css">
    .rating-container span,.rating-container span:hover~span {
          color: ' . $color . ';
    }
    .rating-container:hover span{
          color: ' . $hovar_color . ';
    }
     .rating-container .average {
          color:' . $selected_color . ';
    }
    .rating-container .fa {                                                       font-size: ' . $star_size . ' !important;
    }
    </style>';

    ?>

<div class="comments-rating">
    <div class="rating-container" data-id="<?php echo $post_id ?>">
        <?php echo gkr_load_rating_markup($post_id); ?>
    </div>
    <div id="error"></div>
</div>
<span class="keen-result">(<?php echo $total_row; ?>)</span>
<?php
}

register_activation_hook(__FILE__, 'gkr_create_custom_database_rating_table');
function gkr_create_custom_database_rating_table()
{
    global $wpdb;
    $table_name = $wpdb->prefix . "keen_rating";
    $charset_collate = $wpdb->get_charset_collate();

    $sql = "CREATE TABLE IF NOT EXISTS $table_name (
      id mediumint(9) NOT NULL AUTO_INCREMENT,
      time timestamp DEFAULT '0000-00-00 00:00:00' NOT NULL,
      post_id mediumint(9) NOT NULL,
      rating mediumint(9) NOT NULL,
      ip varchar(55) NOT NULL,
      PRIMARY KEY  (id)
    ) $charset_collate;";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
}

function gkr_load_rating_markup($id)
{

    if (!isset($id)) {
        return;
    }
    $average_rat = 0;

    global $wpdb;
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    $table_name = $wpdb->prefix . "keen_rating";
    $html = '';

    $total_row = $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE (post_id = '" . $id . "')");

    $rating_sum = $wpdb->get_var("SELECT SUM(rating) FROM $table_name WHERE (post_id = '" . $id . "')");

    if (isset($rating_sum) && isset($total_row)) {
        $average_rat = ceil($rating_sum / $total_row);
    }

    for ($i = 1; $i <= 5; $i++) :
        $average = $i <= $average_rat ? 'average' : '';
        $html .= sprintf('<span id="star" class="fa fa-star %1s"></span>', $average, $id, $i);
    endfor;

    return $html;
}

/**
 * Star Rating Plugin Display Data
 */
function gkr_ajax_display_data()
{
    global $wpdb;
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    $table_name = $wpdb->prefix . "keen_rating";

    $post_id = sanitize_text_field(wp_unslash($_POST['postid']));
    $rating = sanitize_text_field(wp_unslash($_POST['rating']));
    $ip = $_SERVER['REMOTE_ADDR'];


    if (isset($post_id) && isset($ip)) {

        $check_user_like = $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE (post_id = '" . $post_id . "' AND ip = '" . $ip . "')");

        if ($check_user_like == true) {
            echo 'You already rated this post';
        } else {

            $wpdb->insert(
                '' . $table_name . '',
                array(
                    'post_id' => $post_id,
                    'rating' => $rating,
                    'ip' => $ip
                ),
                array(
                    '%d',
                    '%d',
                    '%s'
                )
            );
        }
    }

    $total_row = $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE (post_id = '" . $post_id . "')");

    $ratingData = [
        'load_marcup' => gkr_load_rating_markup($post_id),
        'total_row' => $total_row,
    ];
    wp_send_json($ratingData);
}

add_action('wp_ajax_gkr_ajax_display_data', 'gkr_ajax_display_data');
add_action('wp_ajax_nopriv_gkr_ajax_display_data', 'gkr_ajax_display_data');

/** Admin Section */
require plugin_dir_path(__FILE__) . 'class/garuda-keen-rating-custom-style.php';

//Plugin Settings Page
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'gkr_add_plugin_page_settings_link');
function gkr_add_plugin_page_settings_link($links)
{
    $links[] = '<a href="' .
        admin_url('options-general.php?page=keen_star_rating') .
        '">' . esc_html('Settings', 'garuda-keen-rating') . '</a>';
    return $links;
}
